/*
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 * statistics.c
 *
 * Copyright (C) 2011-2022, University of Vienna and Vienna Institute for Nature Conservation & Analyses, Andreas Gattringer.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */


#include <assert.h>
#include "statistics.h"
#include "cats_strings/cats_strings.h"


void zero_statistics_stats(struct statistics *stats)
{
        assert(stats != NULL);
        // save some values
        FILE *file = stats->file;
        char **has_been_populated = stats->has_been_populated;
        char **has_been_populated_ts = stats->has_been_populated_ts;
        int32_t *N = stats->populated_by_classes;
        struct string_array *header = stats->stats_header;

        // reset everything
        struct statistics empty = {0};
        *stats = empty;

        // restore some values
        stats->file = file;
        stats->has_been_populated = has_been_populated;
        stats->has_been_populated_ts = has_been_populated_ts;
        stats->populated_by_classes = N;
        stats->stats_header = header;
}


void init_statistics(struct statistics *stats)
{
        struct statistics empty = {0};
        *stats = empty;
}


void cleanup_statistics(struct statistics *stats)
{
        if (stats->stats_header) free_string_array(&stats->stats_header);
}